'<TiCoBasic Header, Headerversion 001.001>
' Foldings                       = 28,82,380
'<Header End>
'ADBASIC-SYSTEM-FILE--V1.00--0000--0000--INC--PRO
'<SMARTFORMAT OFF> do not remove !!!
'
'##############################################################################
'#                        AOUT1_Tico.inc                                      #
'#              INCLUDE-file for PROII AOUT 1/16                              #
'##############################################################################
'#                                                                            #
'#                                                                            #
'#  30.04.2013  mf   creation                                                 #
'#  09.07.2013  MF   Digout_FIFO_Write_Burst                                  #
'#  04.11.2016  mf   Calc_Processdelay
'#                                                                            #
'#                                                                            #
'# Attention:                                                                 #
'#   - Do not copy the first source line (containing                          #
'#     "'ADBASIC-SYSTEM-FILE...") to user files !                             #
'#     Otherwise the Syntax color may be not correct.                         #
'#   - This includefile requires ADbasic 5 or higher!                         #
'#                                                                            #
'##############################################################################

#if adwin_system=ADwin_ProII
#else
#error("This include file can only be used with the ADwin ProII")  
#endif

'<REGION> System

'***************************************************************
''' Converts a process frequency [Hz] into processor ticks (processdelay or cycle time).
''' frequency:  frequency[Hz]
'''*************************************************************
Function Calc_Processdelay(frequency) as long
  
#if prozessor=tico1
  calc_processdelay=50000000/(frequency)
#else
  calc_processdelay=100000000/(frequency)
#endif
  
endfunction
'---------------------------------------------------------------
' If a low-priority process accesses a Pro-module it must not be
' interrupted by any other process !!!
'---------------------------------------------------------------

Sub Sub_Begin_Critical_Section() ''<HIDE>
#If PRIORITAET = LOW
  Begin_Critical_Section
#EndIf
EndSub

Sub Sub_End_Critical_Section() ''<HIDE>
#If PRIORITAET = LOW
  End_Critical_Section
#EndIf
EndSub

'******************************************************************************
'''Switches the LED on or off.
'''value: 
'''+  0 off
'''+  1 on
'''****************************************************************************
SUB Set_LED(value)
  out (80804000H, value)
ENDSUB

'******************************************************************************
'''Checks the LED.
'''+Return:
'''+   0 off
'''+   1 on
'''****************************************************************************
FUNCTION Check_LED() AS Long
  Check_LED=in(80804000h)
ENDFUNCTION

'<ENDREGION>

'<REGION> DIO

'******************************************************************************
'''Sets the digital outputs (channel 0 - 31).
'''value: each bit corresponds to a channel
'''****************************************************************************
SUB Digout_Long(value)
  out (0, value)
ENDSUB

'******************************************************************************
'''Reads back of the output value of the digital
'''+outputs (channel 0 - 31).
'''****************************************************************************
FUNCTION Get_Digout_Long() AS Long
  Get_Digout_Long=in(0)
ENDFUNCTION

'******************************************************************************
'''Reads the digital inputs (channel 0 - 31).
'''****************************************************************************
FUNCTION Digin_Long() AS Long
  Digin_Long=in(100H)
ENDFUNCTION

'******************************************************************************
'''Sets and resets selected digital outputs.
'''set: Bitstring indicating the outputs which should be set
'''clear: Bitstring indicating the outputs which should be reset
'''****************************************************************************
SUB Digout_Bits(set,clear)
  out(20H,set)
  out(21H,clear)
ENDSUB

******************************************************************************
'''Sets selected digital outputs.
'''set: Bitstring indicating the outputs which should be set
'''***************************************************************************
SUB Digout_Set(set)
  out(20H,set)
ENDSUB

******************************************************************************
'''Resets selected digital outputs.
'''clear: Bitstring indicating the outputs which should be reset
'''***************************************************************************
SUB Digout_Reset(clear)
  out(21H,clear)
ENDSUB

'******************************************************************************
'''Sets or resets one channel of a digital output.
'''channel: Number of the output to be set  (0..31)
'''value:
'''+     0 = reset channel
'''+     1 = set channel
'''****************************************************************************
SUB Digout(channel,value)
  out((0021h-(value)),(shift_left(1,(channel))))
ENDSUB

'******************************************************************************
'''Clears Digin Fifo.
'''****************************************************************************
SUB Digin_FIFO_Clear()
  out(80804880h, 0) 'FIFO clear
ENDSUB

'******************************************************************************
'''Clears Digout Fifo.
'''****************************************************************************
SUB Digout_FIFO_Clear()
  out(80804880h, 0) 'FIFO clear
ENDSUB

'******************************************************************************
'''Enables Digin Fifo.
'''pattern: each bit corresponds to a channel
'''****************************************************************************
SUB Digin_FIFO_Enable(pattern)
  out(80804890h, pattern) 'FIFO clear
ENDSUB

'******************************************************************************
'''Determines which input channels the edge detection unit will be monitored.
'''pattern: each bit corresponds to a channel
'''****************************************************************************
SUB Digout_FIFO_Enable(pattern)
  out(80804890h, pattern) 'FIFO clear
ENDSUB

'******************************************************************************
'''Returns the number of saved value pairs in the FIFO of the edge detection unit.
'''****************************************************************************
FUNCTION Digin_FIFO_Full() as Long
  Digin_FIFO_Full=in(80804880h) AND 0FFFFH
ENDFUNCTION

'******************************************************************************
'''Returns the number of free value pairs in the edge output FIFO.
'''****************************************************************************
FUNCTION Digout_FIFO_Empty() as Long
  Digout_FIFO_Empty=in(80804882h)
ENDFUNCTION

'******************************************************************************
'''Sets the FIFO operation mode: input with edge detection or edge output.
'''value:
'''+    0 Use FiFo as Input (default)
'''+    1 Use FiFo as Output absolute
'''+    2 reserved 
'''+    3 Use FiFo as Output relative
'''+     Mode 1 available from Version 
'''+     DIO TiCo >=E0.3 or DIO TiCo-100 >=E0.1
'''****************************************************************************
SUB Dig_FIFO_Mode(value)
  out(80804870h, value) 
ENDSUB

'******************************************************************************
'''Starts output pattern.
'''****************************************************************************
SUB Digout_FIFO_Start()
  out(4860h, 1)
ENDSUB

'******************************************************************************
'''Reads one value pair from the FIFO of the edge detection unit and writes them into 2 variables.
'''value_by_ref: Variable where the level status bit pattern is written
'''+Each level status bit corresponds to a digital input (see table below).
'''timestamp_by_ref: Variable where the time stamp is written.
'''****************************************************************************
SUB Digin_FIFO_Read(value_by_ref,timestamp_by_ref)
  SUB_BEGIN_CRITICAL_SECTION
  value_by_ref=in(310H)
  timestamp_by_ref=in(310H)
  SUB_END_CRITICAL_SECTION
ENDSUB

'******************************************************************************
'''Writes value pairs into the output edge FIFO.
'''value: variable where the level status bit pattern is written
'''timestamp: variable where the time stamp is written
'''****************************************************************************
SUB Digout_FIFO_Write(value,timestamp)
  SUB_BEGIN_CRITICAL_SECTION
  out(310H,value)
  out(310H,timestamp)
  SUB_END_CRITICAL_SECTION
ENDSUB

******************************************************************************
'''Writes time stamps and output values into DIO FIFO (faster then digout_fifo_write)
'''array[]: array of values and time stamps  
'''+     array[1]  = value 1
'''+     array[2]  = time stamp 1
'''+     array[3]  = value 2 
'''+     array[4]  = time stamp 2
'''+       ...
'''+     array[n]  = value n
'''+     array[n+1]= time stamp n
'''startindex: start index in target arrays for data storage
'''count: number of value pairs (check with Digout_Fifo_Empty)
'''****************************************************************************
SUB Digout_FIFO_Write_Burst(array[], startindex, count) 
  
  dim temp1,temp2 as Integer  
  
  temp1 = startindex 'durch dieses umkopieren ist Konstante und Variable mglich
  temp2 = count

  if ( If_Location_Extern(array)=1) then 'extern 

    begin_critical_section ()         
    asm{
      
      ldc array 'loads the start pointer of Data_1 in the A Register      
      ldi @___Digout_FIFO_Write_Burst@temp1  'loads the startindex in A Register (start pointer of Data_1 will be shifted to B register)
   
      add   'adds A and B register      
      stindexe2 (nop)   'Index e register2 points to data_1[startindex], to start from this point
      
      ldi @___Digout_FIFO_Write_Burst@temp2 'loads numvalues in A Register
      shl 1 'count *2
       
      loop ma_loop_WDE + #Macro_call_count  'loops with "numvalues" repitions
      '------------ start of the loop
      ldie2+ (nop)  'load value to A Register and Increment index Register
      out 310H         'Output A Register
      
      '-----------  'End of the loop 
      ma_loop_WDE + #Macro_call_count :
    }end_asm 
    end_critical_section ()
    
  else
    begin_critical_section ()     
    asm{
      
      ldc array 'darray'data[ data_no ] 'loads the start pointer of Data_1 in the A Register      
      ldi @___Digout_FIFO_Write_Burst@temp1'loads the startindex in A Register (start pointer of Data_1 will be shifted to B register)
      add   'adds A and B register      
      stindex2 (nop)   'Index e register2 points to data_1[startindex], to start from this point      
     
      ldi @___Digout_FIFO_Write_Burst@temp2 'loads numvalues in A Register
      shl 1 'count *2
       
      loop ma_loop_WDL + #Macro_call_count  'loops with "numvalues" repitions
      '------------ start of the loop
      ldi2+ (nop)  'load value to A Register and Increment index Register
      out 310H         'Output A Register
      
      '-----------  'End of the loop 
      ma_loop_WDL + #Macro_call_count :
    }end_asm 
    end_critical_section ()
    
  endif
  
endsub

'''******************************************************************************
'''Reads 100 MHz FIFO timer.
'''+ This timer runs synchronous to the 50 MHz TiCo timer.
'''+ In difference to the TiCo timer, this timer will not be set to 0 while core reset.
'''******************************************************************************
FUNCTION Digin_FIFO_Read_Timer() AS LONG
  Digin_FIFO_Read_Timer = IN(0311H)
ENDFUNCTION

'******************************************************************************
'''Reads 100 MHz FIFO timer.
'''+ This timer runs synchronous to the 50 MHz TiCo timer.
'''+ In difference to the TiCo timer, this timer will not be set to 0 while core reset.
'''*****************************************************************************
FUNCTION Digout_FIFO_Read_Timer() AS LONG
  Digout_FIFO_Read_Timer = IN(0311H)
ENDFUNCTION

'******************************************************************************
'''Reads one of the Latch Registers, which detect, if rising / falling edges
'''+ occured on the digital inputs (channel 0 - 31)
'''+ (These registers are cleared on reading)
'''edge:
'''+     0 latch register for the falling edges
'''+     1 latch register for the rising edges
'''****************************************************************************
FUNCTION Digin_Edge(edge) AS Long
  if (edge = 1) then
    Digin_Edge=in(300H) ' read lath register for rising edges
  else
    Digin_Edge=in(301H) '  ...  for falling edges
  endif
ENDFUNCTION

'*******************************************************************************
'''Activates or deactivates the external Event input.
'''value:
'''+     0 deactivate
'''+     1 activate
'''*****************************************************************************
SUB Event_Enable(value)
  'DIM old AS Long
  '
  'old=in(80804800h)
  'old =(old AND 0FFFFFFFEH) or value
  'out (80804800h, old)
  
  out(80804800h,(in(80804800h) AND 0FFFFFFFEH) or value)

ENDSUB

'*******************************************************************************
'''Configures the external Event input.
'''min_hold:
'''+     0=15 ns (default) 
'''+     1 =50 ns
'''edge:
'''+      1 rising edge (default)
'''+      2 falling edge
'''+      3 rising & falling edge
'''       prescale : 1 to 255
'''****************************************************************************
SUB Event_Config(min_hold,edge,prescale)
  out (80804800h,(in(80804800h) AND 0FFFFFFE3H) or shift_left((min_hold AND 1),4) or shift_left((edge AND 3),2))
  out (80804810h,prescale AND 0FFH)
ENDSUB

'*******************************************************************************
'''Creates an event for the master cpu.
'''*****************************************************************************
SUB Trigger_Event()
  out (108041E0h, 1)
ENDSUB

'<ENDREGION>

'<REGION> DAC

'********************************** DAC ***************************************
'''Converts the digitial value to an analog output.
'''dac_no: channel number of analog output (1..1)
'''value: output value (0..65535)
'''******************************************************************************
SUB DAC(dac_no, value)
  out(22FFh + dac_no,value)
ENDSUB

'********************************** DAC ***************************************
'''Converts the digitial value to analog output 1 and dio output 15..31
'''value:  
'''+ Bit 0..15 (Dac Value) 0.65535
'''+ Bit 16..31 (Dio Value ) Bit 16 ..31
'''******************************************************************************
SUB DAC1_DIO(value)
  out(2610h,value)
ENDSUB

'******************************************************************************
'''Sets DAC-register to desired value.
'''DAC_No: channel number of analog output (1..1)
'''value:  output value (0..65535)
'''******************************************************************************
SUB Write_DAC(dac_no, value)
  out(21FFh + dac_no,value)
  nops(3)
ENDSUB

'********************************************************************************
'''Simultaneously start conversion of all DAC on this module.
'''******************************************************************************
SUB Start_DAC()
  out(7002h,0)
ENDSUB

********************************************************************************
'''Defines the next voltage ramp and starts DAC output
'''+ before use: check if buffer free P2_DAC_Ramp_BufferFree
'''+ Ramp output stops automatically at the end if no new ramp is defined
'''channel: 1
'''start_value: start value (0..65535) of DAC ramp
'''end_value: end value (0...65535) of DAC ramp
'''dio_start: 0000 xxxx H ... FFFFxxxx H
'''dio_end:   0000 xxxx H ... FFFFxxxx H
'''time: duration (20, 40, ... 65520) of the ramp in ns
'''out_mode: bit pattern to set output mode
'''+ Bit 1 DAC ramp
'''+ Bit 2 digital value dio_start at ramp start
'''+ Bit 3 digital value dio_end at ramp end
'''+
'''+ bit = 1: enable output; bit = 0: disable output
'''******************************************************************************
SUB DAC_Ramp_Write(channel,start_value,end_value,dio_start,dio_end,time,out_mode)
  
  dim ts as long  
  dim ti as long
  dim ds,de as long
  
  ti=((time)/20)
  if (ti<1) then ti=1
  
  ds=start_value AND 0FFFFH
  de=end_value AND 0FFFFH
  
  out(80802200H,ds or (dio_start And 0FFFF0000H))
  out(80802201H,de or (dio_end And 0FFFF0000H))
  if (ds=de) then '`= 
    out(80802202H ,ti) 
  else
    if (ds<de) then '+
      ts=(((de-ds)*16384))/ti  
      if (ts<1) then ts=1 
      out(80802202H ,ts)
    else '-
      ts=(((ds-de)*16384))/ti
      if (ts<1) then ts=1 
      out(80802202H ,-ts)
    endif
  endif
   
  out(80802203H,out_mode)
  nop
 
ENDSUB

*********************************************************************************
'''Gets ramp status.
'''channel: 1
'''+ <>0 running 
'''+ 0 stop
'''******************************************************************************
Function DAC_Ramp_Status(channel) as long
  DAC_Ramp_STATUS=in(2600H) AND 111B
ENDFUNCTION

*********************************************************************************
'''Checks if buffer free.
'''channel: 1
'''+ >=0 free
'''+ <0 not free
'''******************************************************************************
Function DAC_Ramp_Buffer_Free(channel) as long
  DAC_Ramp_Buffer_Free=in(2600H)
ENDFUNCTION

*********************************************************************************
'''Stops Ramp mode. 
'''channel: 1
'''******************************************************************************
SUB DAC_Ramp_Stop(channel)
  out(2600H,1)
  nops(3)
endsub

'<ENDREGION>








