%{
#include <string.h>
#include <stdio.h>
#include <linux/adwin.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <sys/types.h>
#include <grp.h>
#include <pwd.h>

#include <adwin-macros.h>
#include <libadwin/limits.h>

extern adwin_dev_t device_list[MAX_DEVICES];
extern int configured_devices;

#include "configfile.h"
extern int lex_line_count;
adwin_dev_t new_dev;
void configFileerror(const char *);
int configFilelex(void);
#define YYERROR_VERBOSE	1
%}

%name-prefix "configFile"
/* %name-prefix "configFile"
 * [BISON][configfile_yacc] Building parser with bison 3.3.2
 * Warnung: POSIX Yacc does not support string literals [-Wyacc]
 * Warnung: POSIX Yacc does not support %name-prefix  [-Wyacc]
 * Warnung: veraltete Direktive, benutzen Sie „%define api.prefix {configFile}“ [-Wdeprecated]
 * 
 * %define api.prefix {configFile}
 * Warning: POSIX Yacc does not support %define [-Wyacc]
 */

%union {
	int val;
	char str[40];
}

%token <val> sectionhead
%token <str> eq
/*
 * token associate operators
 * <...>: see union above
 */
%token <str> STR
%token <str> IPSTR
%token <val> VAL
%token <val> DEVTYPE
%token <str> FLEXERR

/* commands add, del */
%left  <val> UID	/* optional, default "root" */
%left  <val> GID	/* optional, default "adwin" (if exists) else "root" */
%left  <val> MODE	/* optional, default 0660 */
%left  <str> DESC	/* optional, device description text */
%left  <val> TYPE	/* required, one of { link, net, usb } */
%left  <val> BASE	/* required if TYPE=link */
%left  <val> SERIAL	/* required if TYPE=usb */
%left  <str> IP		/* required if TYPE=net */
%left  <val> PORT	/* optional if TYPE=net, default 6543 */
%left  <str> PW		/* optional if TYPE=net, default "" */
%left  <val> HOSTLINK	/* optional if TYPE=net, default 0 */
%left  <val> TIMEOUT	/* optional if TYPE=net, default 1000 */
%left  <val> COUNT	/* optional if TYPE=net, default 5 */

%type <val> val
%type <val> devtype
%type <str> str
%type <str> ip
%type <str> flexerr

%%
sections:     section 
            | sections section
;
section:    
            | sectionhead assignments {
	// process new device
	new_dev.dev_name = $1;
	PRINTDEBUG(DBG_CONFIGFILE, ("found device: %d\n", $1));
	device_list[configured_devices] = new_dev;
	configured_devices++;
	clearDevice(&new_dev);
}
;
assignments:  assignment 
            | assignments assignment
;
assignment: 
MODE eq val	{ new_dev.dev_mode = yylval.val; }
| MODE flexerr	{ }

| TYPE eq devtype { new_dev.dev_type = yylval.val; }
| TYPE flexerr	{ }

| PORT eq val	{ new_dev.dev_net_server.sin_port = htons(yylval.val); }
| PORT flexerr	{ }

| UID eq val	{ 
	//if (getpwuid(yylval.val)) {
	//	fprintf(stderr, "warning: no such user %d\n", yylval.val);
	//}
	new_dev.dev_uid = yylval.val;
}
| UID eq str { }
| UID flexerr	{ fprintf(stderr, "UID flexerr\n"); }

| GID eq val	{ 
	//if (getgrgid(yylval.val)) {
	//	fprintf(stderr, "warning: no such group %d\n", yylval.val);
	//}
	new_dev.dev_gid = yylval.val;
}
| GID eq str	{ }
| GID flexerr  { /* will never reach this (aborted) */ }

| BASE eq val	{ new_dev.dev_link_base_addr = yylval.val; }
| BASE flexerr	{ }

| SERIAL eq val	{ new_dev.dev_usb_serial = yylval.val; }
| SERIAL flexerr	{ }

| HOSTLINK eq val	{ new_dev.dev_net_host_link = yylval.val; }
| HOSTLINK flexerr	{ }

| COUNT eq val	{ new_dev.dev_net_package_count = yylval.val; }
| COUNT flexerr	{ }

| TIMEOUT eq val	{ new_dev.dev_net_timeout = yylval.val; }
| TIMEOUT flexerr	{ }

| DESC eq str	{ strncpy(new_dev.dev_desc, yylval.str, DESCLEN);}
| DESC flexerr	{ }

| PW eq str	{ strncpy(new_dev.dev_net_host_password, yylval.str, PWLEN); }
| PW flexerr	{ }

| IP eq ip	{ inet_aton(yylval.str, &new_dev.dev_net_server.sin_addr); }
| IP flexerr	{  }

;

flexerr:  FLEXERR	{ YYABORT; }			;
devtype:  DEVTYPE	{  }	;
ip:	  IPSTR		{  }	;
str:	  STR		{  }	;
val:	  VAL		{  }	;


%%
#define VALDUMP(x)	printf("%s = %d\n", #x, x)
#define STRDUMP(x)	printf("%s = %s\n", #x, x)

void configFileerror(const char *s) {
    fprintf(stderr, "line %d: %s\n", lex_line_count, s);
}
